function [ret,x0,str,ts,xts]=sime(t,x,u,flag);
%SIMUL_E	is the M-file description of the SIMULINK system named SIMUL_E.
%	The block-diagram can be displayed by typing: SIMUL_E.
%
%	SYS=SIMUL_E(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIMUL_E to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIMUL_E with a FLAG of zero:
%	[SIZES]=SIMUL_E([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[250,42,928,563])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     'Tf')
set_param(sys,'Min step size', 'dtint')
set_param(sys,'Max step size', 'dtint')
set_param(sys,'Relative error','tol')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Sensor',13,'Noises'].

new_system([sys,'/',['Sensor',13,'Noises']])
set_param([sys,'/',['Sensor',13,'Noises']],'Location',[10,41,245,461])


%     Subsystem  ['Sensor',13,'Noises/Sensor Noise 1'].

new_system([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/',['Sensor',13,'Noises/Sensor Noise 1/Out_1']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1/Out_1']],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/',['Sensor',13,'Noises/Sensor Noise 1/Gain']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Sensor',13,'Noises/Sensor Noise 1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/',['Sensor',13,'Noises/Sensor Noise 1/White Noise']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],[50,50;80,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],[200,50;225,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],[125,50;150,50])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],...
		'Mask Entries','[0.001/10000]\/[0.001]\/[555]\/')


%     Finished composite block ['Sensor',13,'Noises/Sensor Noise 1'].

set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 1']],...
		'orientation',2,...
		'position',[140,42,185,78])


%     Subsystem  ['Sensor',13,'Noises/Sensor Noise 6'].

new_system([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/',['Sensor',13,'Noises/Sensor Noise 6/Out_1']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6/Out_1']],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/',['Sensor',13,'Noises/Sensor Noise 6/Gain']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Sensor',13,'Noises/Sensor Noise 6/Zero-Order',13,'Hold']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/',['Sensor',13,'Noises/Sensor Noise 6/White Noise']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],[50,50;80,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],[200,50;225,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],[125,50;150,50])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],...
		'Mask Entries','[0.001/10000]\/[0.001]\/[378144266]\/')


%     Finished composite block ['Sensor',13,'Noises/Sensor Noise 6'].

set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 6']],...
		'orientation',2,...
		'position',[140,352,185,388])


%     Subsystem  ['Sensor',13,'Noises/Sensor Noise 5'].

new_system([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/',['Sensor',13,'Noises/Sensor Noise 5/Out_1']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5/Out_1']],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/',['Sensor',13,'Noises/Sensor Noise 5/Gain']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Sensor',13,'Noises/Sensor Noise 5/Zero-Order',13,'Hold']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/',['Sensor',13,'Noises/Sensor Noise 5/White Noise']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],[50,50;80,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],[200,50;225,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],[125,50;150,50])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],...
		'Mask Entries','[0.001/10000]\/[0.001]\/[1276390893]\/')


%     Finished composite block ['Sensor',13,'Noises/Sensor Noise 5'].

set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 5']],...
		'orientation',2,...
		'position',[140,287,185,323])


%     Subsystem  ['Sensor',13,'Noises/Sensor Noise 4'].

new_system([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/',['Sensor',13,'Noises/Sensor Noise 4/Out_1']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4/Out_1']],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/',['Sensor',13,'Noises/Sensor Noise 4/Gain']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Sensor',13,'Noises/Sensor Noise 4/Zero-Order',13,'Hold']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/',['Sensor',13,'Noises/Sensor Noise 4/White Noise']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],[50,50;80,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],[200,50;225,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],[125,50;150,50])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],...
		'Mask Entries','[0.001/10000]\/[0.001]\/[1278763832]\/')


%     Finished composite block ['Sensor',13,'Noises/Sensor Noise 4'].

set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 4']],...
		'orientation',2,...
		'position',[140,227,185,263])


%     Subsystem  ['Sensor',13,'Noises/Sensor Noise 3'].

new_system([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/',['Sensor',13,'Noises/Sensor Noise 3/Out_1']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3/Out_1']],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/',['Sensor',13,'Noises/Sensor Noise 3/Gain']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Sensor',13,'Noises/Sensor Noise 3/Zero-Order',13,'Hold']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/',['Sensor',13,'Noises/Sensor Noise 3/White Noise']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],[50,50;80,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],[200,50;225,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],[125,50;150,50])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],...
		'Mask Entries','[0.001/10000]\/[0.001]\/[575523602]\/')


%     Finished composite block ['Sensor',13,'Noises/Sensor Noise 3'].

set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 3']],...
		'orientation',2,...
		'position',[140,167,185,203])


%     Subsystem  ['Sensor',13,'Noises/Sensor Noise 2'].

new_system([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/',['Sensor',13,'Noises/Sensor Noise 2/Out_1']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2/Out_1']],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/',['Sensor',13,'Noises/Sensor Noise 2/Gain']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Sensor',13,'Noises/Sensor Noise 2/Zero-Order',13,'Hold']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/',['Sensor',13,'Noises/Sensor Noise 2/White Noise']])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],[50,50;80,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],[200,50;225,50])
add_line([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],[125,50;150,50])
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],...
		'Mask Entries','[0.001/10000]\/[0.001]\/[253731698]\/')


%     Finished composite block ['Sensor',13,'Noises/Sensor Noise 2'].

set_param([sys,'/',['Sensor',13,'Noises/Sensor Noise 2']],...
		'orientation',2,...
		'position',[140,102,185,138])

add_block('built-in/Mux',[sys,'/',['Sensor',13,'Noises/Mux2']])
set_param([sys,'/',['Sensor',13,'Noises/Mux2']],...
		'orientation',2,...
		'hide name',0,...
		'inputs','6',...
		'position',[45,115,75,225])

add_block('built-in/Outport',[sys,'/',['Sensor',13,'Noises/out_1']])
set_param([sys,'/',['Sensor',13,'Noises/out_1']],...
		'orientation',2,...
		'position',[15,160,35,180])
add_line([sys,'/',['Sensor',13,'Noises']],[135,370;90,370;80,220])
add_line([sys,'/',['Sensor',13,'Noises']],[135,305;100,305;100,200;80,200])
add_line([sys,'/',['Sensor',13,'Noises']],[135,245;105,245;105,180;80,180])
add_line([sys,'/',['Sensor',13,'Noises']],[135,185;115,185;115,160;80,160])
add_line([sys,'/',['Sensor',13,'Noises']],[135,120;115,120;115,140;80,140])
add_line([sys,'/',['Sensor',13,'Noises']],[135,60;105,60;105,120;80,120])
add_line([sys,'/',['Sensor',13,'Noises']],[40,170;40,170])


%     Finished composite block ['Sensor',13,'Noises'].

set_param([sys,'/',['Sensor',13,'Noises']],...
		'orientation',2,...
		'position',[545,125,575,165])

%eaj add_block('built-in/Transfer Fcn',[sys,'/',['Kanai-Tajimi',13,'Filter']])
%eaj set_param([sys,'/',['Kanai-Tajimi',13,'Filter']],...
%eaj 		'Numerator','numeq',...
%eaj 		'Denominator','deneq',...
%eaj 		'position',[100,92,175,128])
%eaj 
%eaj 
%eaj %     Subsystem  ['Band-Limited',13,'White Noise'].
%eaj 
%eaj new_system([sys,'/',['Band-Limited',13,'White Noise']])
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise']],'Location',[54,341,339,470])
%eaj 
%eaj add_block('built-in/Outport',[sys,'/',['Band-Limited',13,'White Noise/Out_1']])
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise/Out_1']],...
%eaj 		'position',[230,40,250,60])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/',['Band-Limited',13,'White Noise/Gain']])
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise/Gain']],...
%eaj 		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
%eaj 		'position',[155,31,195,69])
%eaj 
%eaj add_block('built-in/Zero-Order Hold',[sys,'/',['Band-Limited',13,'White Noise/Zero-Order',13,'Hold']])
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise/Zero-Order',13,'Hold']],...
%eaj 		'Sample time','Ts',...
%eaj 		'position',[85,34,120,66])
%eaj 
%eaj add_block('built-in/White Noise',[sys,'/',['Band-Limited',13,'White Noise/White Noise']])
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise/White Noise']],...
%eaj 		'Seed','seed',...
%eaj 		'position',[25,40,45,60])
%eaj add_line([sys,'/',['Band-Limited',13,'White Noise']],[50,50;80,50])
%eaj add_line([sys,'/',['Band-Limited',13,'White Noise']],[200,50;225,50])
%eaj add_line([sys,'/',['Band-Limited',13,'White Noise']],[125,50;150,50])
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise']],...
%eaj 		'Mask Display','plot(t(:),r2(:))',...
%eaj 		'Mask Type','Continuous White Noise.')
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise']],...
%eaj 		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise']],...
%eaj 		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise']],...
%eaj 		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise']],...
%eaj 		'Mask Entries','[2*pi]\/[0.001]\/[101077219]\/')
%eaj 
%eaj 
%eaj %     Finished composite block ['Band-Limited',13,'White Noise'].
%eaj 
%eaj set_param([sys,'/',['Band-Limited',13,'White Noise']],...
%eaj 		'position',[35,92,80,128])

add_block('built-in/From File',[sys,'/',['Earthquake',13,'(in Volts, time scaled)']])
set_param([sys,'/',['Earthquake',13,'(in Volts, time scaled)']],...
		'File name','hach_a.mat',...
		'position',[65,31,175,59])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[280,71,310,104])

add_block('built-in/State-Space',[sys,'/',['Plant',13,'(Evaluation Model)']])
set_param([sys,'/',['Plant',13,'(Evaluation Model)']],...
		'A','At',...
		'B','Bt',...
		'C','Ct',...
		'D','Dt',...
		'position',[345,69,420,111])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[3,41,621,461])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'orientation',1,...
		'position',[250,10,270,30])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'orientation',1,...
		'hide name',0,...
		'outputs','13',...
		'position',[67,50,573,75])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux2'])
set_param([sys,'/','Subsystem/Mux2'],...
		'orientation',1,...
		'hide name',0,...
		'inputs','6',...
		'position',[268,320,392,335])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'orientation',1,...
		'Port','2',...
		'position',[600,320,620,340])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'orientation',1,...
		'hide name',0,...
		'outputs','6',...
		'position',[164,395,596,415])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux  '])
set_param([sys,'/','Subsystem/Mux  '],...
		'orientation',1,...
		'hide name',0,...
		'inputs','11',...
		'position',[45,675,655,690])

add_block('built-in/Transfer Fcn',[sys,'/',['Subsystem/~Integrator ',13,'GA']])
set_param([sys,'/',['Subsystem/~Integrator ',13,'GA']],...
		'orientation',1,...
		'Numerator','[39.5 0]',...
		'Denominator','[39.5 8.89 1]',...
		'position',[483,470,577,510])

add_block('built-in/Transfer Fcn',[sys,'/',['Subsystem/~Integrator ',13,'Am']])
set_param([sys,'/',['Subsystem/~Integrator ',13,'Am']],...
		'orientation',1,...
		'Numerator','[39.5 0]',...
		'Denominator','[39.5 8.89 1]',...
		'position',[438,530,532,570])

add_block('built-in/Transfer Fcn',[sys,'/',['Subsystem/~Integrator ',13,'A3']])
set_param([sys,'/',['Subsystem/~Integrator ',13,'A3']],...
		'orientation',1,...
		'Numerator','[39.5 0]',...
		'Denominator','[39.5 8.89 1]',...
		'position',[368,580,462,620])

add_block('built-in/Transfer Fcn',[sys,'/',['Subsystem/~Integrator ',13,'A2']])
set_param([sys,'/',['Subsystem/~Integrator ',13,'A2']],...
		'orientation',1,...
		'Numerator','[39.5 0]',...
		'Denominator','[39.5 8.89 1]',...
		'position',[253,540,347,580])

add_block('built-in/Transfer Fcn',[sys,'/',['Subsystem/~Integrator ',13,'A1']])
set_param([sys,'/',['Subsystem/~Integrator ',13,'A1']],...
		'orientation',1,...
		'Numerator','[39.5 0]',...
		'Denominator','[39.5 8.89 1]',...
		'position',[237,470,333,505])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'orientation',1,...
		'position',[340,720,360,740])

add_block('built-in/Note',[sys,'/','Subsystem/xm'])
set_param([sys,'/','Subsystem/xm'],...
		'position',[210,145,215,150])

add_block('built-in/Note',[sys,'/','Subsystem/a1'])
set_param([sys,'/','Subsystem/a1'],...
		'position',[410,120,415,125])

add_block('built-in/Note',[sys,'/','Subsystem/a2'])
set_param([sys,'/','Subsystem/a2'],...
		'position',[450,135,455,140])

add_block('built-in/Note',[sys,'/','Subsystem/a3'])
set_param([sys,'/','Subsystem/a3'],...
		'position',[490,151,495,156])

add_block('built-in/Note',[sys,'/','Subsystem/am'])
set_param([sys,'/','Subsystem/am'],...
		'position',[530,135,535,140])

add_block('built-in/Note',[sys,'/','Subsystem/ga'])
set_param([sys,'/','Subsystem/ga'],...
		'position',[570,145,575,150])

add_block('built-in/Sum',[sys,'/','Subsystem/Sum'])
set_param([sys,'/','Subsystem/Sum'],...
		'orientation',1,...
		'position',[355,360,375,375])
add_line([sys,'/','Subsystem'],[345,420;345,440;185,440;185,670])
add_line([sys,'/','Subsystem'],[345,440;345,470;405,470;405,520;300,520;300,535])
add_line([sys,'/','Subsystem'],[275,420;275,430;285,430;285,465])
add_line([sys,'/','Subsystem'],[275,430;175,430;175,655;130,655;130,670])
add_line([sys,'/','Subsystem'],[555,420;530,420;530,465])
add_line([sys,'/','Subsystem'],[485,420;470,420;470,515;485,525])
add_line([sys,'/','Subsystem'],[415,420;415,575])
add_line([sys,'/','Subsystem'],[285,510;240,510;240,635;390,635;390,660;405,670])
add_line([sys,'/','Subsystem'],[300,585;300,630;400,630;400,645;460,645;460,670])
add_line([sys,'/','Subsystem'],[415,625;515,625;515,670])
add_line([sys,'/','Subsystem'],[485,575;570,575;570,670])
add_line([sys,'/','Subsystem'],[530,515;625,515;625,670])
add_line([sys,'/','Subsystem'],[530,450;530,455;215,455;215,640;350,640;350,670])
add_line([sys,'/','Subsystem'],[470,450;205,450;205,650;295,650;295,670])
add_line([sys,'/','Subsystem'],[415,445;195,445;195,660;240,670])
add_line([sys,'/','Subsystem'],[205,420;165,420;165,535;75,535;75,670])
add_line([sys,'/','Subsystem'],[260,35;320,45])
add_line([sys,'/','Subsystem'],[610,345;370,355])
add_line([sys,'/','Subsystem'],[350,695;350,715])
add_line([sys,'/','Subsystem'],[560,80;560,215;380,215;380,315])
add_line([sys,'/','Subsystem'],[520,80;520,205;360,205;360,315])
add_line([sys,'/','Subsystem'],[200,80;200,205;280,205;280,315])
add_line([sys,'/','Subsystem'],[400,80;400,155;300,155;300,315])
add_line([sys,'/','Subsystem'],[440,80;440,170;320,170;320,315])
add_line([sys,'/','Subsystem'],[480,80;480,190;340,190;340,315])
add_line([sys,'/','Subsystem'],[330,340;330,345;360,355])
add_line([sys,'/','Subsystem'],[365,380;380,390])


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'orientation',1,...
		'hide name',0,...
		'position',[417,160,528,255])

add_block('built-in/To Workspace',[sys,'/',['Time Vector ',13,'to Workspace']])
set_param([sys,'/',['Time Vector ',13,'to Workspace']],...
		'mat-name','time',...
		'buffer','[n 1 dts]',...
		'position',[120,247,170,263])

add_block('built-in/S-Function',[sys,'/','Quantizer'])
set_param([sys,'/','Quantizer'],...
		'orientation',2,...
		'function name','quantize',...
		'parameters','q',...
		'Mask Display','plot([-4,4],[0,0],[0,0],[-4,4],[-3,-2,-2,-1,-1,0,0,1,1,2,2,3,3,4]-0.5,[-3,-3,-2,-2,-1,-1,0,0,1,1,2,2,3,3])')
set_param([sys,'/','Quantizer'],...
		'Mask Type','Quantizer',...
		'Mask Dialogue','Discretizes input at given interval.|Quantization interval:',...
		'Mask Translate','q = @1;',...
		'Mask Help','Quantizes input in given intervals. ')
set_param([sys,'/','Quantizer'],...
		'Mask Entries','qint\/',...
		'position',[120,332,150,358])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay'])
set_param([sys,'/','Unit Delay'],...
		'orientation',2,...
		'Sample time','0.0002',...
		'position',[65,337,105,353])

%eaj 
%eaj %     Subsystem  'change  to physical'.
%eaj 
%eaj new_system([sys,'/','change  to physical'])
%eaj set_param([sys,'/','change  to physical'],'Location',[206,41,621,416])
%eaj 
%eaj add_block('built-in/Demux',[sys,'/','change  to physical/Demux1'])
%eaj set_param([sys,'/','change  to physical/Demux1'],...
%eaj 		'outputs','13',...
%eaj 		'position',[65,92,110,288])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/','change  to physical/Gain1'])
%eaj set_param([sys,'/','change  to physical/Gain1'],...
%eaj 		'Gain','1/(0.51)',...
%eaj 		'position',[175,82,200,108])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/','change  to physical/Gain'])
%eaj set_param([sys,'/','change  to physical/Gain'],...
%eaj 		'Gain','1/(0.51)',...
%eaj 		'position',[135,57,160,83])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/','change  to physical/Gain2'])
%eaj set_param([sys,'/','change  to physical/Gain2'],...
%eaj 		'Gain','1/(0.51)',...
%eaj 		'position',[210,102,235,128])
%eaj 
%eaj add_block('built-in/Mux',[sys,'/','change  to physical/Mux2'])
%eaj set_param([sys,'/','change  to physical/Mux2'],...
%eaj 		'inputs','13',...
%eaj 		'position',[315,95,375,295])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/','change  to physical/Gain3'])
%eaj set_param([sys,'/','change  to physical/Gain3'],...
%eaj 		'Gain','1/(0.51)',...
%eaj 		'position',[230,132,255,158])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/','change  to physical/Gain4'])
%eaj set_param([sys,'/','change  to physical/Gain4'],...
%eaj 		'Gain','1/(2.04e-2)',...
%eaj 		'position',[150,152,175,178])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/','change  to physical/Gain5'])
%eaj set_param([sys,'/','change  to physical/Gain5'],...
%eaj 		'Gain','1/(2.04e-2)',...
%eaj 		'position',[185,172,210,198])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/','change  to physical/Gain6'])
%eaj set_param([sys,'/','change  to physical/Gain6'],...
%eaj 		'Gain','1/(2.04e-2)',...
%eaj 		'position',[210,192,235,218])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/','change  to physical/Gain7'])
%eaj set_param([sys,'/','change  to physical/Gain7'],...
%eaj 		'Gain','1/(2.04e-2)',...
%eaj 		'position',[240,212,265,238])
%eaj 
%eaj add_block('built-in/Gain',[sys,'/','change  to physical/Gain8'])
%eaj set_param([sys,'/','change  to physical/Gain8'],...
%eaj 		'Gain','1/(0.1)',...
%eaj 		'position',[195,277,220,303])
%eaj 
%eaj add_block('built-in/Inport',[sys,'/','change  to physical/in_1'])
%eaj set_param([sys,'/','change  to physical/in_1'],...
%eaj 		'position',[15,180,35,200])
%eaj 
%eaj add_block('built-in/Outport',[sys,'/','change  to physical/out_1'])
%eaj set_param([sys,'/','change  to physical/out_1'],...
%eaj 		'position',[405,185,425,205])
%eaj add_line([sys,'/','change  to physical'],[115,280;150,320;275,320;310,285])
%eaj add_line([sys,'/','change  to physical'],[225,290;280,290;310,270])
%eaj add_line([sys,'/','change  to physical'],[115,265;125,265;150,290;190,290])
%eaj add_line([sys,'/','change  to physical'],[115,250;125,250;145,270;285,270;310,255])
%eaj add_line([sys,'/','change  to physical'],[115,235;125,235;145,255;280,255;310,240])
%eaj add_line([sys,'/','change  to physical'],[115,220;130,220;145,235;290,235;310,225])
%eaj add_line([sys,'/','change  to physical'],[115,205;130,205;165,225;235,225])
%eaj add_line([sys,'/','change  to physical'],[270,225;285,225;285,210;310,210])
%eaj add_line([sys,'/','change  to physical'],[240,205;270,205;270,195;310,195])
%eaj add_line([sys,'/','change  to physical'],[115,190;155,190;155,205;205,205])
%eaj add_line([sys,'/','change  to physical'],[215,185;255,185;255,180;310,180])
%eaj add_line([sys,'/','change  to physical'],[115,175;145,175;145,185;180,185])
%eaj add_line([sys,'/','change  to physical'],[180,165;310,165])
%eaj add_line([sys,'/','change  to physical'],[115,160;130,160;130,165;145,165])
%eaj add_line([sys,'/','change  to physical'],[260,145;310,150])
%eaj add_line([sys,'/','change  to physical'],[240,115;260,115;260,135;310,135])
%eaj add_line([sys,'/','change  to physical'],[205,95;270,95;270,120;310,120])
%eaj add_line([sys,'/','change  to physical'],[165,70;280,70;310,105])
%eaj add_line([sys,'/','change  to physical'],[115,145;225,145])
%eaj add_line([sys,'/','change  to physical'],[115,130;155,130;205,115])
%eaj add_line([sys,'/','change  to physical'],[115,115;135,115;170,95])
%eaj add_line([sys,'/','change  to physical'],[115,100;115,70;130,70])
%eaj add_line([sys,'/','change  to physical'],[40,190;60,190])
%eaj add_line([sys,'/','change  to physical'],[380,195;400,195])
%eaj 
%eaj 
%eaj %     Finished composite block 'change  to physical'.
%eaj 
%eaj set_param([sys,'/','change  to physical'],...
%eaj 		'position',[485,50,515,100])
%eaj 
add_block('built-in/To Workspace',[sys,'/',['Z Vector to',13,'Workspace']])
set_param([sys,'/',['Z Vector to',13,'Workspace']],...
		'mat-name','zout',...
		'buffer','[n 1 dts]',...
		'position',[550,67,600,83])

add_block('built-in/Saturation',[sys,'/','Saturation '])
set_param([sys,'/','Saturation '],...
		'orientation',2,...
		'Lower Limit','-3',...
		'Upper Limit','3',...
		'position',[175,333,205,357])

add_block('built-in/Discrete State-Space',[sys,'/','Discrete Controller1'])
set_param([sys,'/','Discrete Controller1'],...
		'orientation',2,...
		'A','Adr',...
		'B','Bdr',...
		'C','Cdr',...
		'D','Ddr',...
		'Sample time','0.001',...
		'position',[305,393,420,437])

add_block('built-in/To Workspace',[sys,'/',['Command Signal ',13,'to Workspace']])
set_param([sys,'/',['Command Signal ',13,'to Workspace']],...
		'mat-name','usignal',...
		'buffer','[n 1 dts]',...
		'position',[245,287,295,303])


%     Subsystem  ['Get Nonlinear ',13,'Control'].

new_system([sys,'/',['Get Nonlinear ',13,'Control']])
set_param([sys,'/',['Get Nonlinear ',13,'Control']],'Location',[29,42,830,662])

add_block('built-in/State-Space',[sys,'/',['Get Nonlinear ',13,'Control/Matrix',13,'Gain']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Matrix',13,'Gain']],...
		'orientation',2,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Get Nonlinear ',13,'Control/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).')
set_param([sys,'/',['Get Nonlinear ',13,'Control/Matrix',13,'Gain']],...
		'Mask Entries','u_eq\/',...
		'position',[285,150,315,180])

add_block('built-in/To Workspace',[sys,'/',['Get Nonlinear ',13,'Control/To Workspace1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/To Workspace1']],...
		'orientation',1,...
		'mat-name','ueq',...
		'buffer','[n 1 dts]',...
		'position',[180,230,230,250])

add_block('built-in/Inport',[sys,'/',['Get Nonlinear ',13,'Control/in_1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/in_1']],...
		'orientation',1,...
		'position',[490,180,510,200])

add_block('built-in/To Workspace',[sys,'/',['Get Nonlinear ',13,'Control/Command Signal ',13,'to Workspace2']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Command Signal ',13,'to Workspace2']],...
		'mat-name','xy',...
		'buffer','[n 1 dts]',...
		'position',[555,205,605,225])

add_block('built-in/Outport',[sys,'/',['Get Nonlinear ',13,'Control/out_1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/out_1']],...
		'orientation',3,...
		'position',[150,65,170,85])

add_block('built-in/Sum',[sys,'/',['Get Nonlinear ',13,'Control/Sum1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Sum1']],...
		'orientation',3,...
		'position',[150,115,170,135])

add_block('built-in/Gain',[sys,'/',['Get Nonlinear ',13,'Control/(Rho)']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/(Rho)']],...
		'orientation',3,...
		'Gain','RHO',...
		'position',[120,415,150,445])

add_block('built-in/Switch',[sys,'/',['Get Nonlinear ',13,'Control/Switch']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Switch']],...
		'orientation',2,...
		'Threshold','1',...
		'position',[165,455,195,485])

add_block('built-in/Gain',[sys,'/',['Get Nonlinear ',13,'Control/Gain4',13,'(sigma//e)']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Gain4',13,'(sigma//e)']],...
		'orientation',2,...
		'Gain','1/bw',...
		'position',[375,455,405,485])

add_block('built-in/Abs',[sys,'/',['Get Nonlinear ',13,'Control/Abs']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Abs']],...
		'orientation',2,...
		'position',[325,460,355,480])

add_block('built-in/MATLAB Fcn',[sys,'/',['Get Nonlinear ',13,'Control/Inverse(sigma//e)']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Inverse(sigma//e)']],...
		'orientation',2,...
		'MATLAB Fcn','inv',...
		'position',[240,455,300,485])


%     Subsystem  ['Get Nonlinear ',13,'Control/Sign'].

new_system([sys,'/',['Get Nonlinear ',13,'Control/Sign']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Sign']],'Location',[239,75,547,244])

add_block('built-in/Outport',[sys,'/',['Get Nonlinear ',13,'Control/Sign/out_1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Sign/out_1']],...
		'position',[265,70,285,90])

add_block('built-in/Inport',[sys,'/',['Get Nonlinear ',13,'Control/Sign/in_1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Sign/in_1']],...
		'position',[35,30,55,50])

add_block('built-in/Relational Operator',[sys,'/',['Get Nonlinear ',13,'Control/Sign/Relational',13,'Operator']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Sign/Relational',13,'Operator']],...
		'Operator','>',...
		'position',[140,32,170,63])

add_block('built-in/Sum',[sys,'/',['Get Nonlinear ',13,'Control/Sign/Sum']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Sign/Sum']],...
		'inputs','+-',...
		'position',[215,64,235,91])

add_block('built-in/Relational Operator',[sys,'/',['Get Nonlinear ',13,'Control/Sign/Relational',13,'Operator1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Sign/Relational',13,'Operator1']],...
		'Operator','<',...
		'position',[140,92,170,123])

add_block('built-in/Constant',[sys,'/',['Get Nonlinear ',13,'Control/Sign/Constant']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Sign/Constant']],...
		'Value','0',...
		'position',[65,105,85,125])
add_line([sys,'/',['Get Nonlinear ',13,'Control/Sign']],[60,40;135,40])
add_line([sys,'/',['Get Nonlinear ',13,'Control/Sign']],[95,40;95,100;135,100])
add_line([sys,'/',['Get Nonlinear ',13,'Control/Sign']],[90,115;135,115])
add_line([sys,'/',['Get Nonlinear ',13,'Control/Sign']],[110,115;110,55;135,55])
add_line([sys,'/',['Get Nonlinear ',13,'Control/Sign']],[175,110;185,110;185,85;210,85])
add_line([sys,'/',['Get Nonlinear ',13,'Control/Sign']],[175,50;185,50;185,70;210,70])
add_line([sys,'/',['Get Nonlinear ',13,'Control/Sign']],[240,80;260,80])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Sign']],...
		'Mask Display','')


%     Finished composite block ['Get Nonlinear ',13,'Control/Sign'].

set_param([sys,'/',['Get Nonlinear ',13,'Control/Sign']],...
		'orientation',2,...
		'position',[270,545,300,575])

add_block('built-in/To Workspace',[sys,'/',['Get Nonlinear ',13,'Control/To Workspace2']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/To Workspace2']],...
		'orientation',1,...
		'mat-name','sxsy',...
		'buffer','[n 1 dts]',...
		'position',[400,520,450,540])

add_block('built-in/State-Space',[sys,'/',['Get Nonlinear ',13,'Control/Matrix',13,'Gain1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Matrix',13,'Gain1']],...
		'orientation',1,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Get Nonlinear ',13,'Control/Matrix',13,'Gain1']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).')
set_param([sys,'/',['Get Nonlinear ',13,'Control/Matrix',13,'Gain1']],...
		'Mask Entries','S\/',...
		'position',[475,390,505,420])

add_block('built-in/Constant',[sys,'/',['Get Nonlinear ',13,'Control/Constant']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Constant']],...
		'orientation',2,...
		'Value','0',...
		'position',[320,315,340,335])

add_block('built-in/Switch',[sys,'/',['Get Nonlinear ',13,'Control/Switch1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Switch1']],...
		'orientation',3,...
		'Threshold','0.000001',...
		'position',[130,305,160,335])

add_block('built-in/Abs',[sys,'/',['Get Nonlinear ',13,'Control/Abs1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/Abs1']],...
		'orientation',2,...
		'position',[255,365,285,385])

add_block('built-in/Gain',[sys,'/',['Get Nonlinear ',13,'Control/(Rho)1']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/(Rho)1']],...
		'orientation',3,...
		'Gain','-1',...
		'position',[130,260,160,290])

add_block('built-in/To Workspace',[sys,'/',['Get Nonlinear ',13,'Control/To Workspace']])
set_param([sys,'/',['Get Nonlinear ',13,'Control/To Workspace']],...
		'mat-name','unl',...
		'buffer','[n 1 dts]',...
		'position',[260,270,310,290])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[500,205;500,215;550,215])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[160,470;135,470;135,450])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[500,205;405,205;405,165;320,165])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[160,110;160,90])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[370,470;360,470])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[320,470;305,470])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[235,470;200,470])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[370,470;370,405;230,405;230,460;200,460])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[265,560;225,560;225,480;200,480])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[370,470;370,560;305,560])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[280,165;165,165;165,140])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[205,165;205,225])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[500,205;500,240;490,240;490,385])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[490,425;490,470;410,470])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[425,470;425,515])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[370,470;370,375;290,375])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[135,410;135,340])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[250,375;145,375;145,340])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[315,325;300,325;300,330;155,340])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[145,300;145,295])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[145,255;145,190;155,190;155,140])
add_line([sys,'/',['Get Nonlinear ',13,'Control']],[145,255;200,255;200,280;255,280])


%     Finished composite block ['Get Nonlinear ',13,'Control'].

set_param([sys,'/',['Get Nonlinear ',13,'Control']],...
		'orientation',2,...
		'position',[245,390,275,440])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'orientation',2,...
		'inputs','2',...
		'position',[500,380,535,415])

add_block('built-in/S-Function',[sys,'/',' Quantizer '])
set_param([sys,'/',' Quantizer '],...
		'orientation',2,...
		'function name','quantize',...
		'parameters','q',...
		'Mask Display','plot([-4,4],[0,0],[0,0],[-4,4],[-3,-2,-2,-1,-1,0,0,1,1,2,2,3,3,4]-0.5,[-3,-3,-2,-2,-1,-1,0,0,1,1,2,2,3,3])')
set_param([sys,'/',' Quantizer '],...
		'Mask Type','Quantizer',...
		'Mask Dialogue','Discretizes input at given interval.|Quantization interval:',...
		'Mask Translate','q = @1;',...
		'Mask Help','Quantizes input in given intervals. ')
set_param([sys,'/',' Quantizer '],...
		'Mask Entries','qint\/',...
		'position',[445,402,475,428])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'orientation',1,...
		'hide name',0,...
		'outputs','11',...
		'position',[509,275,641,295])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'orientation',1,...
		'hide name',0,...
		'inputs','2',...
		'position',[530,325,570,345])

add_block('built-in/Saturation',[sys,'/','Saturation'])
set_param([sys,'/','Saturation'],...
		'orientation',2,...
		'Lower Limit','-3',...
		'Upper Limit','3',...
		'position',[595,380,625,400])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[75,245,95,265])
add_line(sys,[315,90;340,90])
add_line(sys,[100,255;115,255])
add_line(sys,[115,345;110,345])
add_line(sys,[170,345;155,345])
add_line(sys,[425,90;445,90;445,155])
add_line(sys,[475,260;575,270])
add_line(sys,[180,45;245,45;245,80;275,80])
add_line(sys,[540,145;500,155])
%eaj add_line(sys,[85,110;95,110])
add_line(sys,[440,90;450,90;450,75;480,75;520,75;545,75])%eaj add_line(sys,[440,90;450,90;450,75;480,75])
%eaj add_line(sys,[520,75;545,75])
add_line(sys,[240,415;230,415;230,345;210,345])
add_line(sys,[60,345;60,175;245,175;245,95;275,95])
add_line(sys,[300,415;280,415])
add_line(sys,[495,400;480,415])
add_line(sys,[222,345;222,295;240,295])%eaj add_line(sys,[170,345;170,295;240,295])
add_line(sys,[60,345;60,480;550,480;540,405])
add_line(sys,[440,415;425,415])
add_line(sys,[550,350;550,360;640,360;630,390])
add_line(sys,[590,390;540,390])
add_line(sys,[565,300;565,305;560,305;560,320])
add_line(sys,[555,300;555,305;540,305;540,320])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
