% This program can be used to design parameters of optimal olynomial
% controllers in "APPLICATION  OF OPTIMAL POLYNOMIAL  CONTROLLER  TO
% A BENCHMARK  PROBLEM" by  A.K. Agrawal, J.N. Yang  and J.C. Wu.
%
% The program will have to be modified appropriately to simulate results
% for a particular controller in the paper.  These instructions are placed
% at appropriate places as comments beginning with SET.
%
% Modified, Erik A. Johnson <johnsone@nd.edu>, Oct. 97, to do the
% evaluations.  Modifications marked with "%eaj" comment.
%
% ************************************************************************
%eaj clear all
%======================================
% LOADING INFORMATION BLOCK
%
%eaj wg=14.3;
%eaj zg=0.3;
sim_inpt
% SET Tf =25.0; for El Centro Earthquake
% SET Tf=18.0; for Hachihohe earthquake
% SET Tf=300.0; for Artificial earthquake
%eaj Tf=25.0;
% SET load Elc_t to load El Centro Earthquake.
% SET load Hach_t to load Hachinohe earthquake
load Elc_t;
T=e(1,:)';
U=e(2,:)';
%======================================
% REDUCED-ORDER SYSTEM BLOCK
%
reduct
A=Ar;
B=Br;
%======================================
% OUTPUT VECTOR BLOCK
%
Czd=Czr(1:12,:);
Czd(2,:)=Czr(2,:)-Czr(1,:);
Czd(3,:)=Czr(3,:)-Czr(2,:);
[l,nstate]=size(Czd);
%======================================
% CONTROLLER WEIGHTING AND DESIGN BLOCK
%
% SET lcont = 1 for linear controllers.
% SET lcont = 2 for nonlinear controllers.
%eaj lcont=1;
% SET the diagonal elements of linear state weighting matrix.
%eaj q=[1  1  1  0  0  0  0  0  1  1  1 6];
Qd=diag(q);
% SET the diagonal elements of nonlinear state weighting matrix.
%eaj q2z=[1  1  1  0  0  0  0  0  1  1  1  2];
Qdi=diag(q2z);
% SET the scalar controller weighting matrix.
%eaj R=4.0;
Q=Czd'*Qd*Czd;
%
% Linear Gain Design
%
[Glin,P,EIG]=lqr(A,B,Q,R);
%
% Nonlinear Gain Design
%
if lcont == 2
Q2=Czd'*Qdi*Czd;
Abar=A-B*Glin;
M2=lyap(Abar',Q2);
Gnlin=inv(R)*B'*M2;
else
M2=zeros(nstate,nstate);
Gnlin=zeros(1,nstate);
end
%======================================
% OBSERVER DESIGN BLOCK
%
% SET nsensor=? to to specify the number of sensors.
%eaj nsensor=5;
%
% Choose the elements of Cyr, Dyr and Fyr corresponding
% to the sensors selected for design of observer.  For example,
% if five sensors measurements out of the measurement vector yr
% are selected, then the elements of yr will be selected as:
% C2      =[Cyr(1:5,:)];
% D2      =[Dyr(1:5,:)];
% F2      =[Fyr(1:5,:)];
% In the following, second element of yr is used as measurement
% for the design of observer.
%
C2      =Cyr(isensors,:);%eaj [Cyr(1:5,:)];
D2      =Dyr(isensors,:);%eaj [Dyr(1:5,:)];
F2      =Fyr(isensors,:);%eaj [Fyr(1:5,:)];
%
[mm,nn]=size(C2);
% SET SW
SW	= 0.5;
% SET SV
SV	= eye(mm);
% Design of Observer Gain Matrix.
L	= lqew(Ar,Er,C2,F2,SW,SV);
% FORM CONTINUOUS STATE-SPACE CONTROLLER
Ac	= A-L*C2;
Bc	= [B-L*D2 L];
Cc	= eye(nn);
Dc	= zeros(nn,mm+1);
% CONVERT TO DISCRETE FORM
[Ad,Bd,Cd,Dd] = c2dm(Ac,Bc,Cc,Dc,0.001,'tustin');
    % 0.001 is the sampling rate of the DSP Board

%eaj save smp_ctrl Ad Bd Cd Dd
echo off
%======================================
