% run.m
%
% This program runs a given  controller for the  Kanai-Tajimi
% and historical earthquake histories (El Centro and Hachinohe),
% which are part BENCHMARK problem.
%
%	Written by: David Preissler
%	Update by: Pete Quast, Erik A. Johnson <johnsone@nd.edu>
%	Last edit: 10-28-97
%
%#########################################################################
disp(sprintf('%d/%02d/%02d %2d:%02d:%07.4f cputime=%.3f',clock,cputime));tic

author	   = 'Agrawal';
author_tag = 'AGR';
multiple_controllers = 0;	% 1 ---> TRUE  0 ---> FALSE
controller_name = 'ctrl_';	% without suffix
if (exist('KT_time')~=1), KT_time = 750; end;
if (exist('EC_time')~=1), EC_time = 25;  end;
if (exist('HA_time')~=1), HA_time = 18;  end;

%#########################################################################


% Define Omega(wg) and Zeta(zg):
wg = input(' Enter the value of wg for the K-T spectrum (default=14.5): ');
zg = input(' Enter the value of zg for the K-T spectrum (default= 0.3): ');
if isempty(wg), wg=14.5; end;   if isempty(zg), zg=0.3; end; %eaj


% which controller to use
lcont=(input(' Use nonlinear controller? (1==>yes,0==>no)  ')~=0)+1;
if isempty(lcont), lcont=1; end;
nsensor=input(' Number of sensors? (1,3,5)  ');
if isempty(nsensor),
	nsensor=5;
elseif (nsensor~=1&nsensor~=3&nsensor~=5),
	error('number of sensors must be 1, 3, or 5.');
end;

if lcont==1, %linear
	q2z = zeros(1,12);
	if nsensor==5,
		q=[1 1 1 0 0 0 0 0 1 1 1 6]; R=4.0;
	elseif nsensor==3,
		q=[1 1 1 0 0 0 0 0 1 1 1 8.5]; R=10.0;
	else,
		q=[1 1 1 0 0 0 0 0 1 1 1 8.5]; R=2.5;
	end;
elseif lcont==2, %cubic
	if nsensor==5,
		q=[1 1 1 0 0 0 0 0 1 1 1 4]; R=10.0;
		q2z=[1 1 1 0 0 0 0 0 1 1 1 2];
	elseif nsensor==3,
		q=[1 1 1 0 0 0 0 0 1 1 1 1]; R=10.0;
		q2z=[1 1 1 0 0 0 0 0 1 1 1 1];
	else,
		q=[1 1 1 0 0 0 0 0 1 1 1 6]; R=60.0;
		q2z=[1 1 1 0 0 0 0 0 1 1 1 3.8];
	end;
elseif lcont==3 && nsensor==1, %cubic but different q2z
		% this q2z was in the paper but was a typo;
		% the one above with [... 3.8] is the correct one;
		% the paper was corrected to reflect this
		q=[1 1 1 0 0 0 0 0 1 1 1 6]; R=60.0;
		q2z=[1 1 1 0 0 0 0 0 1 1 1 3];
else, error(' nonlinear control must be 0 or 1 ');
end;
if     nsensor==5, isensors=1:5;
elseif nsensor==3, isensors=2:4;
else,              isensors=4;
end;

controller_name = [controller_name num2str(min(lcont-1,1)) num2str(nsensor)];
if lcont==3, controller_name=[controller_name 'B']; end;


% Set up the parameters for the simulink system:

% Set up simulation model:

poly_des
	[no,ni]=size(Dd);
	if     nsensor==5, Bd=Bd; Dd=Dd;
	elseif nsensor==3, Bd=[Bd(:,1) zeros(no,1) Bd(:,2:4) zeros(no,1)];
	                   Dd=[Dd(:,1) zeros(no,1) Dd(:,2:4) zeros(no,1)];
	else,              Bd=[Bd(:,1) zeros(no,3) Bd(:,2)   zeros(no,1)];
	                   Dd=[Dd(:,1) zeros(no,3) Dd(:,2)   zeros(no,1)];
	end;
save(controller_name,'Ad','Bd','Cd','Dd','M2','Glin','Gnlin');

%#########################################################################
% Load and run the simulink file for the K-T Earthquake:

   if (exist('dokt')~=1),dokt=1;end; if (dokt),
      rk45('simkt', KT_time, [], [1e-6,1e-4,1e-4,0,0,2]);
   else,
      time=zeros(10,1);
      usignal=zeros(size(time));
      zout=zeros(length(time),13);
   end;
 
   [sig_u,sig_f,sig_xp,J] = eval_kt(zout,usignal);
   clear time usignal zout

%#########################################################################
% Load and run the simulink file for the El Centro Earthquake:
%#########################################################################

   rk45('sime', EC_time, [], [tol,dtint,dtint,0,0,2]);

   [Eu_max,Exp_max,Ef_max,EJ6,EJ7,EJ8,EJ9,EJ10] = eval_e(zout,usignal);
   EJ=[EJ6 EJ7 EJ8 EJ9 EJ10];
   clear time usignal zout

%#########################################################################
% Load and run the simulink file for the Hachinohe Earthquake:
%#########################################################################

   rk45('simh', HA_time, [], [1e-6,1e-4,1e-4,0,0,2]);

   [Hu_max,Hxp_max,Hf_max,HJ6,HJ7,HJ8,HJ9,HJ10] = eval_h(zout,usignal);
   HJ=[HJ6 HJ7 HJ8 HJ9 HJ10];
   clear time usignal zout

%#########################################################################
% Compare the Historical Earthquake data:

   J(6) = max([EJ6, HJ6]);
   J(7) = max([EJ7, HJ7]);
   J(8) = max([EJ8, HJ8]);
   J(9) = max([EJ9, HJ9]); 
   J(10) = max([EJ10, HJ10]);

%#########################################################################

  if (lcont==2), sss='1 (yes)'; else, sss='0 (no)'; end;
  prob_string = sprintf(['nonlinear?  ' sss '\n# of sensors:  %f\n\n'],nsensor);

writefil(controller_name,author,wg,zg,KT_time,prob_string,J, ...
         sig_u,  sig_f,  sig_xp,  ...
         EJ, Eu_max, Ef_max, Exp_max, ...
         HJ, Hu_max, Hf_max, Hxp_max);

disp(sprintf('%d/%02d/%02d %2d:%02d:%07.4f cputime=%.3f',clock,cputime));toc
