% run.m
%
% This program runs a given  controller for the  Kanai-Tajimi
% and historical earthquake histories (El Centro and Hachinohe),
% which are part BENCHMARK problem.
%
%	Written by: David Preissler
%	Update by: Pete Quast, Erik A. Johnson <johnsone@nd.edu>
%	Last edit: 10-31-97
%
%#########################################################################
disp(sprintf('%d/%02d/%02d %2d:%02d:%07.4f cputime=%.3f',clock,cputime));tic

author	   = 'Balas';
author_tag = 'BAL';
multiple_controllers = 0;	% 1 ---> TRUE  0 ---> FALSE
controller_name = 'control';	% without suffix
if (exist('KT_time')~=1), KT_time = 300; end;
if (exist('EC_time')~=1), EC_time = 10;  end;
if (exist('HA_time')~=1), HA_time = 7.2; end;

%#########################################################################


% Define Omega(wg) and Zeta(zg):
wg = input(' Enter the value of wg for the K-T spectrum (default=37.3): ');
zg = input(' Enter the value of zg for the K-T spectrum (default= 0.3): ');
if isempty(wg), wg=37.3; end;   if isempty(zg), zg=0.3; end; %eaj


if multiple_controllers == 1
   controller_suffix = input(' Enter the suffix of the controller: ','s');
   controller_name = [controller_name , controller_suffix ];
end


% Set up simulation model:
sim_inp


% Set up the controller
control
save(controller_name,'Ad','Bd','Cd','Dd');


%#########################################################################
% Load and run the simulink file for the K-T Earthquake:
%#########################################################################

   if (exist('dokt')~=1),dokt=1;end; if (dokt),
      rk45('simkt6', KT_time, [], [1e-6,1e-4,1e-4,0,0,2]);
   else,
      time=zeros(10,1);
      usignal=zeros(size(time));
      zout=zeros(length(time),13);
   end;

   [sig_u,sig_xdotdotam,sig_xm,J] = eval_kt(zout,usignal);
   clear time usignal zout

%#########################################################################
% Load and run the simulink file for the El Centro Earthquake:
%#########################################################################

   rk45('sime6', EC_time, [], [1e-6,1e-4,1e-4,0,0,2]);

   [Eu_max,Exm_max,Exdotdotam_max,EJ6,EJ7,EJ8,EJ9,EJ10] = eval_e(zout,usignal);
   EJ=[EJ6 EJ7 EJ8 EJ9 EJ10];
   clear time usignal zout

%#########################################################################
% Load and run the simulink file for the Hachinohe Earthquake:
%#########################################################################

   rk45('simh6', HA_time, [], [1e-6,1e-4,1e-4,0,0,2]);

   [Hu_max,Hxm_max,Hxdotdotam_max,HJ6,HJ7,HJ8,HJ9,HJ10] = eval_h(zout,usignal);
   HJ=[HJ6 HJ7 HJ8 HJ9 HJ10];
   clear time usignal zout

%#########################################################################
% Compare the Historical Earthquake data:
%#########################################################################

   J(6) = max([EJ6, HJ6]);
   J(7) = max([EJ7, HJ7]);
   J(8) = max([EJ8, HJ8]);
   J(9) = max([EJ9, HJ9]); 
   J(10) = max([EJ10, HJ10]);

%#########################################################################

writefil(controller_name,author,wg,zg,KT_time,'',J, ...
         sig_u,  sig_xdotdotam,  sig_xm,  ...
         EJ, Eu_max, Exdotdotam_max, Exm_max, ...
         HJ, Hu_max, Hxdotdotam_max, Hxm_max);
         
disp(sprintf('%d/%02d/%02d %2d:%02d:%07.4f cputime=%.3f',clock,cputime));toc
