% run.m
%
% This program runs a given  controller for the  Kanai-Tajimi
% and historical earthquake histories (El Centro and Hachinohe),
% which are part BENCHMARK problem.
%
%	Written by: David Preissler
%	Update by: Pete Quast, Erik A. Johnson <johnsone@nd.edu>
%	Last edit: 10-28-97
%
%#########################################################################
disp(sprintf('%d/%02d/%02d %2d:%02d:%07.4f cputime=%.3f',clock,cputime));tic

author	   = 'BaniHaniGhaboussi';
author_tag = 'GHAB';
multiple_controllers = 1;	% 1 ---> TRUE  0 ---> FALSE
controller_name = 'contrl_';	% without suffix
if (exist('KT_time')~=1), KT_time = 750; end;
if (exist('EC_time')~=1), EC_time = 25;  end;
if (exist('HA_time')~=1), HA_time = 18;  end;

%#########################################################################


% Define Omega(wg) and Zeta(zg):
wg = input(' Enter the value of wg for the K-T spectrum (default=14.5): ');
zg = input(' Enter the value of zg for the K-T spectrum (default= 0.3): ');
if isempty(wg), wg=14.5; end;   if isempty(zg), zg=0.3; end; %eaj


% which controller
if multiple_controllers == 1
	controller_suffix = input(' Enter the suffix of the controller (A, B, or C): ','s');
	controller_name = [controller_name , controller_suffix ];
end


% Set up the parameters for the simulink system:
load(controller_name)


% Set up simulation model:
sim_inpt


%#########################################################################
% Load and run the simulink file for the K-T Earthquake:

   if (exist('dokt')~=1),dokt=1;end; if (dokt),
      rk45('simkt', KT_time, [], [1e-6,1e-4,1e-4,0,0,2]);
   else,
      time=zeros(10,1);
      usignal=zeros(size(time));
      zout=zeros(length(time),13);
   end;
 
   [sig_u,sig_f,sig_xp,J] = eval_kt(zout,usignal);
   save([controller_name '_tuz_kt'],'time','usignal','zout');
   clear time usignal zout

%#########################################################################
% Load and run the simulink file for the El Centro Earthquake:
%#########################################################################

   rk45('sime', EC_time, [], [tol,dtint,dtint,0,0,2]);

   [Eu_max,Exp_max,Ef_max,EJ6,EJ7,EJ8,EJ9,EJ10] = eval_e(zout,usignal);
   EJ=[EJ6 EJ7 EJ8 EJ9 EJ10];
   save([controller_name '_tuz_e'],'time','usignal','zout');
   clear time usignal zout

%#########################################################################
% Load and run the simulink file for the Hachinohe Earthquake:
%#########################################################################

   rk45('simh', HA_time, [], [1e-6,1e-4,1e-4,0,0,2]);

   [Hu_max,Hxp_max,Hf_max,HJ6,HJ7,HJ8,HJ9,HJ10] = eval_h(zout,usignal);
   HJ=[HJ6 HJ7 HJ8 HJ9 HJ10];
   save([controller_name '_tuz_h'],'time','usignal','zout');
   clear time usignal zout

%#########################################################################
% Compare the Historical Earthquake data:

   J(6) = max([EJ6, HJ6]);
   J(7) = max([EJ7, HJ7]);
   J(8) = max([EJ8, HJ8]);
   J(9) = max([EJ9, HJ9]); 
   J(10) = max([EJ10, HJ10]);

%#########################################################################

  prob_string = '';

writefil(controller_name,author,wg,zg,KT_time,prob_string,J, ...
         sig_u,  sig_f,  sig_xp,  ...
         EJ, Eu_max, Ef_max, Exp_max, ...
         HJ, Hu_max, Hf_max, Hxp_max);

disp(sprintf('%d/%02d/%02d %2d:%02d:%07.4f cputime=%.3f',clock,cputime));toc
