function [Eu_max,Exp_max,Ef_max,EJ6,EJ7,EJ8,EJ9,EJ10] = eval_e(zout,usignal)

%#########################################################################

%  gains: units ---> volts 
  
gain_x_floor = .25;
gain_x_act   = 7.87;
gain_v_floor = .0102;
gain_v_act   = .394;
gain_a_floor = 0.5;
gain_f_tendon   = 0.222;

%#########################################################################
% Peak Responses for the El Centro Earthquake:

%************************************************************************
% Calculate the Controller Constraints:

% Max of usignal should be less than or equal to 3 volts:

	Eu_max = max(abs(usignal));

% Max displacement should be less than or equal to 3 cm:

	Exp_max = max(abs(zout(:,4)/gain_x_act));

% Max force should be less than or equal to 12 kN:

	Ef_max = max(abs(zout(:,12)/gain_f_tendon));

%************************************************************************
% Calculate the Values of J:

%------------------------------------------------------------------------
% EJ6:

	Ex3o = 6.45;

	Ed1 = zout(:,1)/gain_x_floor;
	Ed1_max = max(abs(Ed1));

	Ed2 = zout(:,2)/gain_x_floor - zout(:,1)/gain_x_floor;
	Ed2_max = max(abs(Ed2));

	Ed3 = zout(:,3)/gain_x_floor - zout(:,2)/gain_x_floor;
	Ed3_max = max(abs(Ed3));

	Ed = [Ed1_max Ed2_max Ed3_max]/Ex3o;
	EJ6 = max(Ed);

%------------------------------------------------------------------------
% EJ7:

	Exdotdota3o = 1.57;

	Exdotdota1 = zout(:,9)/gain_a_floor;
	Exdotdota1_max = max(abs(Exdotdota1));

	Exdotdota2 = zout(:,10)/gain_a_floor;
	Exdotdota2_max = max(abs(Exdotdota2));

	Exdotdota3 = zout(:,11)/gain_a_floor;
	Exdotdota3_max = max(abs(Exdotdota3));

	Exdotdota = [Exdotdota1_max Exdotdota2_max Exdotdota3_max]/Exdotdota3o;
	EJ7 = max(Exdotdota);

%------------------------------------------------------------------------
% EJ8:

	Exp = zout(:,4)/gain_x_act;
	EJ8 = max(abs(Exp)/Ex3o);

%------------------------------------------------------------------------
% EJ9:

	Exdot3o = 99.9;

	Exdotp = zout(:,8)/gain_v_act;
	EJ9 = max(abs(Exdotp)/Exdot3o);

%------------------------------------------------------------------------
% EJ10:

	Weight = 289;
	Ef = zout(:,12)/gain_f_tendon;
	EJ10 = max(abs(Ef)/Weight);

%************************************************************************
% Save some variables:

	%time_e = time;
	%usignal_e = usignal;
	%zout_e = zout;

%#########################################################################
