function [t,x,y] = rk45(sys, time, X0, V1_Options, ut, varargin)
%RK45	SIMULINK 1.x RK45 integration algorithm.
%   RK45 has been superceded by the SIM command. This function is
%   provided for backward compatibility only.  It is mapped to the
%   SIMULINK 2.0 'ode45' algorithm.  For more help type HELP SIM.
%
%  Modified (Erik A. Johnson <johnsone@nd.edu>, 11/5/97) to not take
%  an infinite amount of memory when called without return arguments.

%   Copyright (c) 1990-96 by The MathWorks, Inc.
%   $Revision: 1.17 $

%==============================================================================
% Post obsolete message and do some error checking
%==============================================================================

%eaj -- add start
warning(['RK45 has been replaced by solver ODE45.  Calling SIM(...)']);
warning_lev_cp2wksp = warning; warning('off');
%eaj -- add end

msg = nargchk(2,inf,nargin);
if (~isempty(msg)),
  error(msg);
end

%==============================================================================
% Try to load the block diagram, it may be an M-file (1.3 style), in which
% case sim will treat it as an S-function.  A simple call here will force it
% into memory if it's a block diagram.
%==============================================================================

if exist(sys)==2,
  eval(sys,'');
end

%==============================================================================
% Initialize any missing input parameters (besides varargin)
%==============================================================================

if exist('X0') == 0,
  X0 = [];
end
if exist('V1_Options') == 0,
  V1_Options = zeros(1,6);
end
if exist('ut') == 0,
  ut = [];
end


%==============================================================================
% Map V1.3 options to options structure
%==============================================================================

o1=V1_Options(:).';
opts = simset('Solver','ode45','InitialState',X0);
if (length(o1)>=1 & o1(1)~=0), opts=simset(opts,'RelTol',o1(1)); end;
%2 (minstep) ignored in MATLAB 5
if (length(o1)>=3 & o1(3)~=0), opts=simset(opts,'MaxStep',o1(3),'FixedStep',o1(3)); end;
%4 is ignored in rk45 in MATLAB 4
if (length(o1)>=5 & o1(5)~=0), opts=simset(opts,'Trace','siminfo'); end;
%6 I don't know where to put the plot/noplot (1/2) option -- eaj
simOptions=opts;

%================================================================
% Call the SIM command
%================================================================

% The code before and after the call to sim copies the ToWorkspace
% variables to the caller workspace.
% Note: we must use unique variables names at this point to be
%       distinct from ToWorkspace variable names.
sys_cp2wksp = sys;

%eaj -- here's the original, but commented out
%eaj [t_cp2wksp,x_cp2wksp,y_cp2wksp] = sim(sys,time,simOptions,ut,varargin{:});
%eaj -- here's the start of my replacement code
nargout_cp2wksp = nargout;
eval(sys,'');
args={};
if nargin>=3, args={args{:},simOptions}; end;
if nargin>=4, args={args{:},ut,varargin{:}}; end;
if     nargout==0,                                   sim(sys,time,args{:});
elseif nargout==1,  t_cp2wksp                      = sim(sys,time,args{:});
elseif nargout==2, [t_cp2wksp,x_cp2wksp          ] = sim(sys,time,args{:});
else,              [t_cp2wksp,x_cp2wksp,y_cp2wksp] = sim(sys,time,args{:});
end;
%eaj -- here's the end of my replacement code

% Copy ToWorkspace variables to the caller workspace.
names_cp2wksp = find_system(sys_cp2wksp, 'BlockType', 'ToWorkspace');
for i_cp2wksp = 1:length(names_cp2wksp)
  varname_cp2wksp = get_param(names_cp2wksp{i_cp2wksp}, ...
                              'VariableName');
  assignin('caller', varname_cp2wksp, eval(varname_cp2wksp));
end

% Now safe to use t, x, and y
%eaj -- here's the original, but commented out
%eaj t = t_cp2wksp;
%eaj x = x_cp2wksp;
%eaj y = y_cp2wksp;
%eaj -- here's the start of my replacement code
nargout = nargout_cp2wksp;
if (nargout>=1), t=t_cp2wksp; end;
if (nargout>=2), x=x_cp2wksp; end;
if (nargout>=3), y=y_cp2wksp; end;
warning(warning_lev_cp2wksp);
%eaj -- here's the end of my replacement code
