%   This is a program using CSMC&C method to find out the control gain
%     The designed model is augmented with an additional filter equation   
%
%   Edited by J. C. Wu
%   Oct. 1996

%
%  first need to compute the design model
%  from REDUCT.m 
reduct
%
%  choose the measured outputs and control outputs
%
Cyd=[Cyr(4,:)];
Dyd=[Dyr(4,:)];
Fyd=[Fyr(4,:)];
Czd=Czr(1:12,:);
Dzd=Dzr(1:12,:);
Fzd=Fzr(1:12,:);
Czd(2,:)=Czr(2,:)-Czr(1,:);
Czd(3,:)=Czr(3,:)-Czr(2,:);
Dzd(2,:)=Dzr(2,:)-Dzr(1,:);
Dzd(3,:)=Dzr(3,:)-Dzr(2,:);
Fzd(2,:)=Fzr(2,:)-Fzr(1,:);
Fzd(3,:)=Fzr(3,:)-Fzr(2,:);
[l,nstate]=size(Czd);
%
%   input the filter coefficient
%
[m,nstate]=size(Cyd);
Aeta=eye(m,m)*(-10);
Beta=eye(m,m)*10;
%
%   The augmented system with the filter equation
%
Af=[[Ar  zeros(nstate,m)];[Beta*Cyd  Aeta]];
Bf=[Br;Beta*Dyd];
Cf=[zeros(m,nstate) eye(m,m)];
%
%   The augmented system for computing a stable Ueq for the
%   sliding surface
%
A_star=[Af zeros(size(Af),1)
        zeros(1,size(Af)) 0  ];
B_star=[Bf  zeros(size(Af),1)
         0      1            ];
C_star=[Cf  zeros(m,1)
        zeros(1,size(Af))  1];
%
%  input the control parameters 
%
Qz=diag([6000  700  2000  0  0  0  0  100  0  0  0  100]);
Qeta=diag([100]);
Qq1=1;
Ru=0.1;
Rq1dot=0.1;
%
Q=[Czd'*Qz*Czd  zeros(nstate,m)  zeros(nstate,1)
   zeros(m,nstate)    Qeta       zeros(m,1)
   zeros(1,nstate)   zeros(1,m)    Qq1           ];
S=[Czd'*Qz*Dzd  zeros(nstate,1)
    zeros(m,1)  zeros(m,1)     
    zeros(1,1)  zeros(1,1)];
R=[Dzd'*Qz*Dzd+Ru  0
     0             Rq1dot ];
%
%   compute the LQR output feedback gain by iteration
%

% initial guess of gain matrix K
% for 5 sensors
%K=[  -0.53852652883275  -0.05433098206910  -0.51288615038098  -1.85140753718327     -3.52370220689474                  0
%                  0                  0                  0                  0                     0        3.16227766016838  ];

% for 3 sensors
%K=[-0.23189768947835  -0.57448262107477  -1.31202240537007       0
%         0                0                  0                3.1623 ];

% for 1 sensor 
K=[  -0.92598847665350         0
               0         3.16227766016838 ];
%
%   iteration starts
%
sum0=0;
for i=1:2
for j=1:m+1
 sum0=sum0+abs(K(i,j));
end
end

niter=2000;
for i=1:niter
    i
    Q_pk=Q+C_star'*K'*R*K*C_star-S*K*C_star-C_star'*K'*S';
    M=A_star-B_star*K*C_star;
    PL=lyap(M,eye(nstate+m+1,nstate+m+1));
    PK=lyap(M',Q_pk);
%
    'This is Gain matrix K'
    K=inv(R)*(B_star'*PK*PL*C_star'+S'*PL*C_star')*inv(C_star*PL*C_star')
%
    sum1=0;
    for i=1:2
    for j=1:m+1
       sum1=sum1+abs(K(i,j));
    end
    end
%
    eps1=0.000001;
    err=abs((sum1-sum0)/sum0);
    if err <= eps1
      'Accurate up to eps1 !'
      % check if the controller is stable
      if (max(real(eig(M))) > 0)
        disp('Unstable Controller')
      end
      break
    end
    sum0=sum1;
en
