% CSMC_OBS.m
% This program was used to design a Continuous-Sliding-Mode Controller
% (CSMC) with an Kalman-Bucy filter to estimate the state from the
% measured output.
% following "Structural Control : A Benchmark Comparison" 
%                Part 2 : Active Tendon System
%                by Spencer, Dyke and Deoskar
%
%   Edited by J. C. Wu
%   Aug. 1996
%

%
% Need to construct the DESIGN MODEL
reduct;
%
%
%  choose the measured outputs and control outputs
%
Cyd=Cyr(2:4,:);
Dyd=Dyr(2:4,:);
Fyd=Fyr(2:4,:);
Czd=Czr(1:12,:);
Dzd=Dzr(1:12,:);
Fzd=Fzr(1:12,:);
Czd(2,:)=Czr(2,:)-Czr(1,:);
Czd(3,:)=Czr(3,:)-Czr(2,:);
Dzd(2,:)=Dzr(2,:)-Dzr(1,:);
Dzd(3,:)=Dzr(3,:)-Dzr(2,:);
Fzd(2,:)=Fzr(2,:)-Fzr(1,:);
Fzd(3,:)=Fzr(3,:)-Fzr(2,:);
[m,nstate]=size(Cyd);
[l,nstate]=size(Czd);
[l,r]=size(Dzd);
B1=Br(1:nstate-r,:);
B2=Br(nstate-r+1:nstate,:);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  compute the CSMC control gain  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Input the weighting matrix for sliding surface design
%  and gain margin delta
%
Q0=diag([10  10  10  80  0  0  0  0  100  10  10  110]);
Q=Czr'*Q0*Czr;
delta=diag([80]);
%
%  transformation matrix from Z to zeta
%
D_bar=[eye(nstate-r,nstate-r)  -B1*inv(B2)
       zeros(r,nstate-r)        eye(r,r)];
D_bar_inv=inv(D_bar);
Azeta=D_bar*Ar*D_bar_inv;
Azeta11=Azeta(1:nstate-r,1:nstate-r);
Azeta12=Azeta(1:nstate-r,nstate-r+1:nstate);
Azeta22=Azeta(nstate-r+1:nstate,nstate-r+1:nstate);

Q_t=D_bar_inv'*Q*D_bar_inv;
Q_t11=Q_t(1:nstate-r,1:nstate-r);
Q_t12=Q_t(1:nstate-r,nstate-r+1:nstate);
Q_t22=Q_t(nstate-r+1:nstate,nstate-r+1:nstate);
Q_t22_inv=inv(Q_t22);
%
%  Solve Riccati Eq. for P_star
%
A_bar=Azeta11-Azeta12*Q_t22_inv*Q_t12';
B_bar=Azeta12*Q_t22_inv*Azeta12';
C_bar=Q_t11-Q_t12*Q_t22_inv*Q_t12';
P_star=are(A_bar,B_bar,C_bar);
%
%   compute the sliding surface matrix P
%
Pzeta1=Q_t22_inv*(Azeta12'*P_star+Q_t12');
P=[Pzeta1  eye(r,r)]*D_bar;
%
%   compute the control gain
%
K_b=-inv(P*Br)*P*Ar-delta*Br'*P'*P
K_f=-inv(P*Br)*P*Er
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Compute the observer gain (Kalman-Bucy Filter gain)  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ignore the feedforward
K_f=0.0
Er_bar=Er+Br*K_f;
%
%  input the disturbance and measurement noise intensity
%
SW	= 5;
SV	= eye(m);
L	= lqew(Ar,Er_bar,Cyd,Fyd,SW,SV);
%
% FORM CONTINUOUS STATE-SPACE CONTROLLER
%
Ac	= Ar + Br*K_b - L*Cyd - L*Dyd*K_b;
Bc	= L;
Cc	= K_b;
Dc	= zeros(r,m);

% CHECK STABILITY OF CONTROLLER
if (max(real(eig(Ac))) > 0) 
	disp(' ')
	disp('UNSTABLE CONTROLLER !')
end

% CONVERT TO DISCRETE FORM
[Ad,Bd,Cd,Dd] = c2dm(Ac,Bc,Cc,Dc,0.001,'tustin');
    % 0.001 is the sampling rate of the DSP Board

save smp_ctrl Ad Bd Cd Dd
echo off
